pub struct EmbeddingModel { /* private fields */ }Expand description
Embedding model for generating semantic embeddings
Implementations
Sourceimpl EmbeddingModel
impl EmbeddingModel
Sourcepub async fn new(config: EmbeddingConfig) -> Result<Self>
pub async fn new(config: EmbeddingConfig) -> Result<Self>
Create new embedding model with real Candle inference
Sourcepub fn encode(&mut self, text: &str) -> Result<Embedding>
pub fn encode(&mut self, text: &str) -> Result<Embedding>
Generate embedding for a single text using TRUE BERT neural network inference
Sourcepub fn encode_batch(&mut self, texts: &[String]) -> Result<Vec<Embedding>>
pub fn encode_batch(&mut self, texts: &[String]) -> Result<Vec<Embedding>>
Generate embeddings for multiple texts
Sourcepub fn encode_batch_parallel(
&mut self,
texts: &[String],
) -> Result<(Vec<Embedding>, Vec<String>)>
pub fn encode_batch_parallel( &mut self, texts: &[String], ) -> Result<(Vec<Embedding>, Vec<String>)>
Generate embeddings for multiple texts with parallel processing and error recovery
Sourcepub fn encode_batch_with_retry(
&mut self,
texts: &[String],
max_retries: usize,
retry_delay_ms: u64,
) -> Result<(Vec<Embedding>, Vec<String>, usize)>
pub fn encode_batch_with_retry( &mut self, texts: &[String], max_retries: usize, retry_delay_ms: u64, ) -> Result<(Vec<Embedding>, Vec<String>, usize)>
Batch encoding with retry logic and graceful error handling
Sourcepub fn clear_cache(&mut self)
pub fn clear_cache(&mut self)
Clear the embedding cache
Sourcepub fn cache_size(&self) -> usize
pub fn cache_size(&self) -> usize
Get cache size
Sourcepub fn config(&self) -> &EmbeddingConfig
pub fn config(&self) -> &EmbeddingConfig
Get model configuration
Sourcepub fn has_tokenizer(&self) -> bool
pub fn has_tokenizer(&self) -> bool
Check if real tokenizer is loaded
Sourcepub fn health_check(&self) -> EmbeddingHealth
pub fn health_check(&self) -> EmbeddingHealth
Get embedding model health status
Sourcepub fn clear_cache_selective(&mut self, keep_recent: Option<usize>)
pub fn clear_cache_selective(&mut self, keep_recent: Option<usize>)
Clear cache with optional size limit
Sourcepub fn cache_stats(&self) -> CacheStats
pub fn cache_stats(&self) -> CacheStats
Get cache statistics